==> opengtl_0.9.5.orig.tar.gz: OpenGTL-0.9.5/OpenGTL/GTLCore/AST/Tree.h <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * version 2 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _AST_TREE_H_
#define _AST_TREE_H_

#include <list>
#include <GTLCore/ScopedName.h>

namespace llvm {
  class Module;
}

namespace GTLCore {
  class CodeGenerator;
  class VariableNG;
  class Type;
  class ModuleData;
  namespace AST {
    class Expression;
    class FunctionDeclaration;
    /**
     * @internal
     * @ingroup GTLCore_AST
     */
    class GlobalConstantDeclaration {
      public:
        GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, Expression* _initialiser);
        ~GlobalConstantDeclaration();
        GTLCore::ScopedName name() const { return m_name; }
        const Expression* initialiser() const { return m_initialiser; }
        Expression* initialiser() { return m_initialiser; }
        GTLCore::VariableNG* variable() { return m_variable; }
        void generate( ModuleData* _module, GTLCore::CodeGenerator* _codeGenerator);
      private:
        GTLCore::ScopedName m_name;
        Expression* m_initialiser;
        GTLCore::VariableNG* m_variable;
        const GTLCore::Type* m_type;
    };
    /**
     * @internal
     * @ingroup GTLCore_AST
     */
    class Tree {
      public:
        Tree();
        ~Tree();
        const std::list<FunctionDeclaration*>& functionsDeclarations() const;
        void append(FunctionDeclaration* fd);
        const std::list<GlobalConstantDeclaration*>& globalConstantDeclarations() const;
        void append( GlobalConstantDeclaration* constant );
        bool containsGlobalConstant( const GTLCore::ScopedName& _name ) const;
        void generate( ModuleData* _module, GTLCore::CodeGenerator* _codeGenerator);
      private:
        std::list<FunctionDeclaration*> m_functions;
        std::list<GlobalConstantDeclaration*> m_globalConstants;
    };
  }
}

#endif

==> opengtl_0.9.9.orig.tar.gz: OpenGTL-0.9.9/OpenGTL/GTLCore/AST/Tree.h <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _AST_TREE_H_
#define _AST_TREE_H_

#include <list>
#include <GTLCore/ScopedName.h>

namespace llvm {
  class Module;
}

namespace GTLCore {
  class CodeGenerator;
  class VariableNG;
  class Type;
  class ModuleData;
  namespace AST {
    class Expression;
    class FunctionDeclaration;
    /**
     * @internal
     * @ingroup GTLCore_AST
     */
    class GlobalConstantDeclaration {
      public:
        GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, Expression* _initialiser, bool _dependant);
        GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, const std::list< int >& sizes,bool _dependant);
        ~GlobalConstantDeclaration();
        GTLCore::ScopedName name() const { return m_name; }
        const Expression* initialiser() const { return m_initialiser; }
        Expression* initialiser() { return m_initialiser; }
        GTLCore::VariableNG* variable() { return m_variable; }
        void generate( ModuleData* _module, GTLCore::CodeGenerator* _codeGenerator);
      private:
        GTLCore::ScopedName m_name;
        Expression* m_initialiser;
        GTLCore::VariableNG* m_variable;
        const GTLCore::Type* m_type;
        std::list< int > m_sizes;
        bool m_constant;
    };
    /**
     * @internal
     * @ingroup GTLCore_AST
     */
    class Tree {
      public:
        Tree();
        ~Tree();
        const std::list<FunctionDeclaration*>& functionsDeclarations() const;
        void append(FunctionDeclaration* fd);
        const std::list<GlobalConstantDeclaration*>& globalConstantDeclarations() const;
        void append( GlobalConstantDeclaration* constant );
        bool containsGlobalConstant( const GTLCore::ScopedName& _name ) const;
        void generate( ModuleData* _module, GTLCore::CodeGenerator* _codeGenerator);
      private:
        std::list<FunctionDeclaration*> m_functions;
        std::list<GlobalConstantDeclaration*> m_globalConstants;
    };
  }
}

#endif
